# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .node_input_compiled_chat_history_value import NodeInputCompiledChatHistoryValue
from .node_input_compiled_error_value import NodeInputCompiledErrorValue
from .node_input_compiled_json_value import NodeInputCompiledJsonValue
from .node_input_compiled_number_value import NodeInputCompiledNumberValue
from .node_input_compiled_search_results_value import NodeInputCompiledSearchResultsValue
from .node_input_compiled_string_value import NodeInputCompiledStringValue


class NodeInputVariableCompiledValue_String(NodeInputCompiledStringValue):
    type: typing_extensions.Literal["STRING"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class NodeInputVariableCompiledValue_Number(NodeInputCompiledNumberValue):
    type: typing_extensions.Literal["NUMBER"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class NodeInputVariableCompiledValue_Json(NodeInputCompiledJsonValue):
    type: typing_extensions.Literal["JSON"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class NodeInputVariableCompiledValue_ChatHistory(NodeInputCompiledChatHistoryValue):
    type: typing_extensions.Literal["CHAT_HISTORY"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class NodeInputVariableCompiledValue_SearchResults(NodeInputCompiledSearchResultsValue):
    type: typing_extensions.Literal["SEARCH_RESULTS"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class NodeInputVariableCompiledValue_Error(NodeInputCompiledErrorValue):
    type: typing_extensions.Literal["ERROR"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


NodeInputVariableCompiledValue = typing.Union[
    NodeInputVariableCompiledValue_String,
    NodeInputVariableCompiledValue_Number,
    NodeInputVariableCompiledValue_Json,
    NodeInputVariableCompiledValue_ChatHistory,
    NodeInputVariableCompiledValue_SearchResults,
    NodeInputVariableCompiledValue_Error,
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .register_prompt_prompt import RegisterPromptPrompt
from .registered_prompt_deployment import RegisteredPromptDeployment
from .registered_prompt_model_version import RegisteredPromptModelVersion
from .registered_prompt_sandbox import RegisteredPromptSandbox
from .registered_prompt_sandbox_snapshot import RegisteredPromptSandboxSnapshot

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class RegisterPromptResponse(pydantic.BaseModel):
    prompt: RegisterPromptPrompt = pydantic.Field(description="Information about the generated prompt")
    sandbox_snapshot: RegisteredPromptSandboxSnapshot = pydantic.Field(
        description="Information about the generated sandbox snapshot"
    )
    sandbox: RegisteredPromptSandbox = pydantic.Field(description="Information about the generated sandbox")
    model_version: RegisteredPromptModelVersion = pydantic.Field(
        description="Information about the generated model version"
    )
    prompt_version_id: str = pydantic.Field(description="The ID of the generated prompt version")
    deployment: RegisteredPromptDeployment = pydantic.Field(description="Information about the generated deployment")

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.jsonable_encoder import jsonable_encoder
from ...types.document_index_read import DocumentIndexRead
from ...types.entity_status import EntityStatus
from ...types.environment_enum import EnvironmentEnum

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class DocumentIndexesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create(
        self,
        *,
        label: str,
        name: str,
        status: typing.Optional[EntityStatus] = OMIT,
        environment: typing.Optional[EnvironmentEnum] = OMIT,
        indexing_config: typing.Dict[str, typing.Any],
        copy_documents_from_index_id: typing.Optional[str] = OMIT,
    ) -> DocumentIndexRead:
        """
        Creates a new document index.

        Parameters:
            - label: str. A human-readable label for the document index

            - name: str. A name that uniquely identifies this index within its workspace

            - status: typing.Optional[EntityStatus]. The current status of the document index

                                                     * `ACTIVE` - Active
                                                     * `ARCHIVED` - Archived
            - environment: typing.Optional[EnvironmentEnum]. The environment this document index is used in

                                                             * `DEVELOPMENT` - Development
                                                             * `STAGING` - Staging
                                                             * `PRODUCTION` - Production
            - indexing_config: typing.Dict[str, typing.Any]. Configuration representing how documents should be indexed

            - copy_documents_from_index_id: typing.Optional[str]. Optionally specify the id of a document index from which you'd like to copy and re-index its documents into this newly created index
        ---
        from vellum import EntityStatus, EnvironmentEnum
        from vellum.client import Vellum

        client = Vellum(
            api_key="YOUR_API_KEY",
        )
        client.document_indexes.create(
            label="string",
            name="string",
            status=EntityStatus.ACTIVE,
            environment=EnvironmentEnum.DEVELOPMENT,
            indexing_config={"string": {"unknown": "string", "type": "unknown"}},
        )
        """
        _request: typing.Dict[str, typing.Any] = {"label": label, "name": name, "indexing_config": indexing_config}
        if status is not OMIT:
            _request["status"] = status
        if environment is not OMIT:
            _request["environment"] = environment
        if copy_documents_from_index_id is not OMIT:
            _request["copy_documents_from_index_id"] = copy_documents_from_index_id
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", "v1/document-indexes"),
            json=jsonable_encoder(_request),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(DocumentIndexRead, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def retrieve(self, id: str) -> DocumentIndexRead:
        """
        Used to retrieve a Document Index given its ID or name.

        Parameters:
            - id: str. Either the Document Index's ID or its unique name
        ---
        from vellum.client import Vellum

        client = Vellum(
            api_key="YOUR_API_KEY",
        )
        client.document_indexes.retrieve(
            id="string",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", f"v1/document-indexes/{id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(DocumentIndexRead, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncDocumentIndexesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create(
        self,
        *,
        label: str,
        name: str,
        status: typing.Optional[EntityStatus] = OMIT,
        environment: typing.Optional[EnvironmentEnum] = OMIT,
        indexing_config: typing.Dict[str, typing.Any],
        copy_documents_from_index_id: typing.Optional[str] = OMIT,
    ) -> DocumentIndexRead:
        """
        Creates a new document index.

        Parameters:
            - label: str. A human-readable label for the document index

            - name: str. A name that uniquely identifies this index within its workspace

            - status: typing.Optional[EntityStatus]. The current status of the document index

                                                     * `ACTIVE` - Active
                                                     * `ARCHIVED` - Archived
            - environment: typing.Optional[EnvironmentEnum]. The environment this document index is used in

                                                             * `DEVELOPMENT` - Development
                                                             * `STAGING` - Staging
                                                             * `PRODUCTION` - Production
            - indexing_config: typing.Dict[str, typing.Any]. Configuration representing how documents should be indexed

            - copy_documents_from_index_id: typing.Optional[str]. Optionally specify the id of a document index from which you'd like to copy and re-index its documents into this newly created index
        ---
        from vellum import EntityStatus, EnvironmentEnum
        from vellum.client import AsyncVellum

        client = AsyncVellum(
            api_key="YOUR_API_KEY",
        )
        await client.document_indexes.create(
            label="string",
            name="string",
            status=EntityStatus.ACTIVE,
            environment=EnvironmentEnum.DEVELOPMENT,
            indexing_config={"string": {"unknown": "string", "type": "unknown"}},
        )
        """
        _request: typing.Dict[str, typing.Any] = {"label": label, "name": name, "indexing_config": indexing_config}
        if status is not OMIT:
            _request["status"] = status
        if environment is not OMIT:
            _request["environment"] = environment
        if copy_documents_from_index_id is not OMIT:
            _request["copy_documents_from_index_id"] = copy_documents_from_index_id
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", "v1/document-indexes"),
            json=jsonable_encoder(_request),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(DocumentIndexRead, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def retrieve(self, id: str) -> DocumentIndexRead:
        """
        Used to retrieve a Document Index given its ID or name.

        Parameters:
            - id: str. Either the Document Index's ID or its unique name
        ---
        from vellum.client import AsyncVellum

        client = AsyncVellum(
            api_key="YOUR_API_KEY",
        )
        await client.document_indexes.retrieve(
            id="string",
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", f"v1/document-indexes/{id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(DocumentIndexRead, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .model_version_build_config import ModelVersionBuildConfig
from .model_version_exec_config import ModelVersionExecConfig
from .model_version_read_status_enum import ModelVersionReadStatusEnum
from .provider_enum import ProviderEnum

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class ModelVersionRead(pydantic.BaseModel):
    id: str = pydantic.Field(description="Vellum-generated ID that uniquely identifies this model version.")
    created: dt.datetime = pydantic.Field(description="Timestamp of when this model version was created.")
    label: str = pydantic.Field(description="Human-friendly name for this model version.")
    provider: ProviderEnum = pydantic.Field(
        description=(
            "Which LLM provider this model version is associated with.\n"
            "\n"
            "- `ANTHROPIC` - Anthropic\n"
            "- `AWS_BEDROCK` - AWS Bedrock\n"
            "- `AZURE_OPENAI` - Azure OpenAI\n"
            "- `COHERE` - Cohere\n"
            "- `GOOGLE` - Google\n"
            "- `HOSTED` - Hosted\n"
            "- `MOSAICML` - MosaicML\n"
            "- `OPENAI` - OpenAI\n"
            "- `FIREWORKS_AI` - Fireworks AI\n"
            "- `HUGGINGFACE` - HuggingFace\n"
            "- `MYSTIC` - Mystic\n"
            "- `PYQ` - Pyq\n"
            "- `REPLICATE` - Replicate\n"
        )
    )
    external_id: str = pydantic.Field(
        description="The unique id of this model version as it exists in the above provider's system."
    )
    build_config: ModelVersionBuildConfig = pydantic.Field(
        description="Configuration used to build this model version."
    )
    exec_config: ModelVersionExecConfig = pydantic.Field(
        description="Configuration used to execute this model version."
    )
    status: typing.Optional[ModelVersionReadStatusEnum]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .workflow_output_array import WorkflowOutputArray
from .workflow_output_chat_history import WorkflowOutputChatHistory
from .workflow_output_error import WorkflowOutputError
from .workflow_output_function_call import WorkflowOutputFunctionCall
from .workflow_output_image import WorkflowOutputImage
from .workflow_output_json import WorkflowOutputJson
from .workflow_output_number import WorkflowOutputNumber
from .workflow_output_search_results import WorkflowOutputSearchResults
from .workflow_output_string import WorkflowOutputString


class WorkflowOutput_String(WorkflowOutputString):
    type: typing_extensions.Literal["STRING"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowOutput_Number(WorkflowOutputNumber):
    type: typing_extensions.Literal["NUMBER"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowOutput_Json(WorkflowOutputJson):
    type: typing_extensions.Literal["JSON"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowOutput_ChatHistory(WorkflowOutputChatHistory):
    type: typing_extensions.Literal["CHAT_HISTORY"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowOutput_SearchResults(WorkflowOutputSearchResults):
    type: typing_extensions.Literal["SEARCH_RESULTS"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowOutput_Error(WorkflowOutputError):
    type: typing_extensions.Literal["ERROR"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowOutput_Array(WorkflowOutputArray):
    type: typing_extensions.Literal["ARRAY"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowOutput_FunctionCall(WorkflowOutputFunctionCall):
    type: typing_extensions.Literal["FUNCTION_CALL"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowOutput_Image(WorkflowOutputImage):
    type: typing_extensions.Literal["IMAGE"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


WorkflowOutput = typing.Union[
    WorkflowOutput_String,
    WorkflowOutput_Number,
    WorkflowOutput_Json,
    WorkflowOutput_ChatHistory,
    WorkflowOutput_SearchResults,
    WorkflowOutput_Error,
    WorkflowOutput_Array,
    WorkflowOutput_FunctionCall,
    WorkflowOutput_Image,
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .prompt_execution_meta import PromptExecutionMeta
from .prompt_output import PromptOutput

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class FulfilledExecutePromptResponse(pydantic.BaseModel):
    """
    The successful response from the model containing all of the resolved values generated by the prompt.
    """

    meta: typing.Optional[PromptExecutionMeta]
    raw: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(
        description="The subset of the raw response from the model that the request opted into with `expand_raw`."
    )
    execution_id: str = pydantic.Field(description="The ID of the execution.")
    outputs: typing.List[PromptOutput]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .array_variable_value import ArrayVariableValue
from .chat_history_variable_value import ChatHistoryVariableValue
from .error_variable_value import ErrorVariableValue
from .function_call_variable_value import FunctionCallVariableValue
from .json_variable_value import JsonVariableValue
from .number_variable_value import NumberVariableValue
from .search_results_variable_value import SearchResultsVariableValue
from .string_variable_value import StringVariableValue


class VariableValue_String(StringVariableValue):
    type: typing_extensions.Literal["STRING"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class VariableValue_Number(NumberVariableValue):
    type: typing_extensions.Literal["NUMBER"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class VariableValue_Json(JsonVariableValue):
    type: typing_extensions.Literal["JSON"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class VariableValue_ChatHistory(ChatHistoryVariableValue):
    type: typing_extensions.Literal["CHAT_HISTORY"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class VariableValue_SearchResults(SearchResultsVariableValue):
    type: typing_extensions.Literal["SEARCH_RESULTS"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class VariableValue_Error(ErrorVariableValue):
    type: typing_extensions.Literal["ERROR"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class VariableValue_Array(ArrayVariableValue):
    type: typing_extensions.Literal["ARRAY"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class VariableValue_FunctionCall(FunctionCallVariableValue):
    type: typing_extensions.Literal["FUNCTION_CALL"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


VariableValue = typing.Union[
    VariableValue_String,
    VariableValue_Number,
    VariableValue_Json,
    VariableValue_ChatHistory,
    VariableValue_SearchResults,
    VariableValue_Error,
    VariableValue_Array,
    VariableValue_FunctionCall,
]

VariableValue_Array.update_forward_refs()



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .workflow_result_event_output_data_chat_history import WorkflowResultEventOutputDataChatHistory
from .workflow_result_event_output_data_error import WorkflowResultEventOutputDataError
from .workflow_result_event_output_data_json import WorkflowResultEventOutputDataJson
from .workflow_result_event_output_data_number import WorkflowResultEventOutputDataNumber
from .workflow_result_event_output_data_search_results import WorkflowResultEventOutputDataSearchResults
from .workflow_result_event_output_data_string import WorkflowResultEventOutputDataString


class WorkflowResultEventOutputData_String(WorkflowResultEventOutputDataString):
    type: typing_extensions.Literal["STRING"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowResultEventOutputData_Number(WorkflowResultEventOutputDataNumber):
    type: typing_extensions.Literal["NUMBER"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowResultEventOutputData_Json(WorkflowResultEventOutputDataJson):
    type: typing_extensions.Literal["JSON"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowResultEventOutputData_ChatHistory(WorkflowResultEventOutputDataChatHistory):
    type: typing_extensions.Literal["CHAT_HISTORY"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowResultEventOutputData_SearchResults(WorkflowResultEventOutputDataSearchResults):
    type: typing_extensions.Literal["SEARCH_RESULTS"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class WorkflowResultEventOutputData_Error(WorkflowResultEventOutputDataError):
    type: typing_extensions.Literal["ERROR"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


WorkflowResultEventOutputData = typing.Union[
    WorkflowResultEventOutputData_String,
    WorkflowResultEventOutputData_Number,
    WorkflowResultEventOutputData_Json,
    WorkflowResultEventOutputData_ChatHistory,
    WorkflowResultEventOutputData_SearchResults,
    WorkflowResultEventOutputData_Error,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import httpx

from ..environment import VellumEnvironment


class BaseClientWrapper:
    def __init__(self, *, api_key: str, environment: VellumEnvironment):
        self.api_key = api_key
        self._environment = environment

    def get_headers(self) -> typing.Dict[str, str]:
        headers: typing.Dict[str, str] = {
            "X-Fern-Language": "Python",
            "X-Fern-SDK-Name": "vellum-ai",
            "X-Fern-SDK-Version": "v0.2.1",
        }
        headers["X_API_KEY"] = self.api_key
        return headers

    def get_environment(self) -> VellumEnvironment:
        return self._environment


class SyncClientWrapper(BaseClientWrapper):
    def __init__(self, *, api_key: str, environment: VellumEnvironment, httpx_client: httpx.Client):
        super().__init__(api_key=api_key, environment=environment)
        self.httpx_client = httpx_client


class AsyncClientWrapper(BaseClientWrapper):
    def __init__(self, *, api_key: str, environment: VellumEnvironment, httpx_client: httpx.AsyncClient):
        super().__init__(api_key=api_key, environment=environment)
        self.httpx_client = httpx_client



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .code_execution_node_chat_history_result import CodeExecutionNodeChatHistoryResult
from .code_execution_node_error_result import CodeExecutionNodeErrorResult
from .code_execution_node_json_result import CodeExecutionNodeJsonResult
from .code_execution_node_number_result import CodeExecutionNodeNumberResult
from .code_execution_node_search_results_result import CodeExecutionNodeSearchResultsResult
from .code_execution_node_string_result import CodeExecutionNodeStringResult


class CodeExecutionNodeResultOutput_String(CodeExecutionNodeStringResult):
    type: typing_extensions.Literal["STRING"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class CodeExecutionNodeResultOutput_Number(CodeExecutionNodeNumberResult):
    type: typing_extensions.Literal["NUMBER"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class CodeExecutionNodeResultOutput_Json(CodeExecutionNodeJsonResult):
    type: typing_extensions.Literal["JSON"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class CodeExecutionNodeResultOutput_ChatHistory(CodeExecutionNodeChatHistoryResult):
    type: typing_extensions.Literal["CHAT_HISTORY"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class CodeExecutionNodeResultOutput_SearchResults(CodeExecutionNodeSearchResultsResult):
    type: typing_extensions.Literal["SEARCH_RESULTS"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class CodeExecutionNodeResultOutput_Error(CodeExecutionNodeErrorResult):
    type: typing_extensions.Literal["ERROR"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


CodeExecutionNodeResultOutput = typing.Union[
    CodeExecutionNodeResultOutput_String,
    CodeExecutionNodeResultOutput_Number,
    CodeExecutionNodeResultOutput_Json,
    CodeExecutionNodeResultOutput_ChatHistory,
    CodeExecutionNodeResultOutput_SearchResults,
    CodeExecutionNodeResultOutput_Error,
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .templating_node_chat_history_result import TemplatingNodeChatHistoryResult
from .templating_node_error_result import TemplatingNodeErrorResult
from .templating_node_json_result import TemplatingNodeJsonResult
from .templating_node_number_result import TemplatingNodeNumberResult
from .templating_node_search_results_result import TemplatingNodeSearchResultsResult
from .templating_node_string_result import TemplatingNodeStringResult


class TemplatingNodeResultOutput_String(TemplatingNodeStringResult):
    type: typing_extensions.Literal["STRING"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class TemplatingNodeResultOutput_Number(TemplatingNodeNumberResult):
    type: typing_extensions.Literal["NUMBER"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class TemplatingNodeResultOutput_Json(TemplatingNodeJsonResult):
    type: typing_extensions.Literal["JSON"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class TemplatingNodeResultOutput_ChatHistory(TemplatingNodeChatHistoryResult):
    type: typing_extensions.Literal["CHAT_HISTORY"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class TemplatingNodeResultOutput_SearchResults(TemplatingNodeSearchResultsResult):
    type: typing_extensions.Literal["SEARCH_RESULTS"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class TemplatingNodeResultOutput_Error(TemplatingNodeErrorResult):
    type: typing_extensions.Literal["ERROR"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


TemplatingNodeResultOutput = typing.Union[
    TemplatingNodeResultOutput_String,
    TemplatingNodeResultOutput_Number,
    TemplatingNodeResultOutput_Json,
    TemplatingNodeResultOutput_ChatHistory,
    TemplatingNodeResultOutput_SearchResults,
    TemplatingNodeResultOutput_Error,
]



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.remove_none_from_dict import remove_none_from_dict
from ...types.paginated_slim_workflow_deployment_list import PaginatedSlimWorkflowDeploymentList
from .types.workflow_deployments_list_request_status import WorkflowDeploymentsListRequestStatus

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class WorkflowDeploymentsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        ordering: typing.Optional[str] = None,
        status: typing.Optional[WorkflowDeploymentsListRequestStatus] = None,
    ) -> PaginatedSlimWorkflowDeploymentList:
        """
        Parameters:
            - limit: typing.Optional[int]. Number of results to return per page.

            - offset: typing.Optional[int]. The initial index from which to return the results.

            - ordering: typing.Optional[str]. Which field to use when ordering the results.

            - status: typing.Optional[WorkflowDeploymentsListRequestStatus]. The current status of the workflow deployment

                                                                             - `ACTIVE` - Active
                                                                             - `ARCHIVED` - Archived---
        from vellum import WorkflowDeploymentsListRequestStatus
        from vellum.client import Vellum

        client = Vellum(
            api_key="YOUR_API_KEY",
        )
        client.workflow_deployments.list(
            status=WorkflowDeploymentsListRequestStatus.ACTIVE,
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", "v1/workflow-deployments"),
            params=remove_none_from_dict({"limit": limit, "offset": offset, "ordering": ordering, "status": status}),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(PaginatedSlimWorkflowDeploymentList, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncWorkflowDeploymentsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        ordering: typing.Optional[str] = None,
        status: typing.Optional[WorkflowDeploymentsListRequestStatus] = None,
    ) -> PaginatedSlimWorkflowDeploymentList:
        """
        Parameters:
            - limit: typing.Optional[int]. Number of results to return per page.

            - offset: typing.Optional[int]. The initial index from which to return the results.

            - ordering: typing.Optional[str]. Which field to use when ordering the results.

            - status: typing.Optional[WorkflowDeploymentsListRequestStatus]. The current status of the workflow deployment

                                                                             - `ACTIVE` - Active
                                                                             - `ARCHIVED` - Archived---
        from vellum import WorkflowDeploymentsListRequestStatus
        from vellum.client import AsyncVellum

        client = AsyncVellum(
            api_key="YOUR_API_KEY",
        )
        await client.workflow_deployments.list(
            status=WorkflowDeploymentsListRequestStatus.ACTIVE,
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", "v1/workflow-deployments"),
            params=remove_none_from_dict({"limit": limit, "offset": offset, "ordering": ordering, "status": status}),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(PaginatedSlimWorkflowDeploymentList, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .terminal_node_chat_history_result import TerminalNodeChatHistoryResult
from .terminal_node_error_result import TerminalNodeErrorResult
from .terminal_node_json_result import TerminalNodeJsonResult
from .terminal_node_number_result import TerminalNodeNumberResult
from .terminal_node_search_results_result import TerminalNodeSearchResultsResult
from .terminal_node_string_result import TerminalNodeStringResult


class TerminalNodeResultOutput_String(TerminalNodeStringResult):
    type: typing_extensions.Literal["STRING"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class TerminalNodeResultOutput_Number(TerminalNodeNumberResult):
    type: typing_extensions.Literal["NUMBER"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class TerminalNodeResultOutput_Json(TerminalNodeJsonResult):
    type: typing_extensions.Literal["JSON"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class TerminalNodeResultOutput_ChatHistory(TerminalNodeChatHistoryResult):
    type: typing_extensions.Literal["CHAT_HISTORY"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class TerminalNodeResultOutput_SearchResults(TerminalNodeSearchResultsResult):
    type: typing_extensions.Literal["SEARCH_RESULTS"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class TerminalNodeResultOutput_Error(TerminalNodeErrorResult):
    type: typing_extensions.Literal["ERROR"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


TerminalNodeResultOutput = typing.Union[
    TerminalNodeResultOutput_String,
    TerminalNodeResultOutput_Number,
    TerminalNodeResultOutput_Json,
    TerminalNodeResultOutput_ChatHistory,
    TerminalNodeResultOutput_SearchResults,
    TerminalNodeResultOutput_Error,
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .function_call_chat_message_content import FunctionCallChatMessageContent
from .image_chat_message_content import ImageChatMessageContent
from .string_chat_message_content import StringChatMessageContent


class ArrayChatMessageContentItem_String(StringChatMessageContent):
    type: typing_extensions.Literal["STRING"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class ArrayChatMessageContentItem_FunctionCall(FunctionCallChatMessageContent):
    type: typing_extensions.Literal["FUNCTION_CALL"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class ArrayChatMessageContentItem_Image(ImageChatMessageContent):
    type: typing_extensions.Literal["IMAGE"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


ArrayChatMessageContentItem = typing.Union[
    ArrayChatMessageContentItem_String, ArrayChatMessageContentItem_FunctionCall, ArrayChatMessageContentItem_Image
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .function_call_chat_message_content_request import FunctionCallChatMessageContentRequest
from .image_chat_message_content_request import ImageChatMessageContentRequest
from .string_chat_message_content_request import StringChatMessageContentRequest


class ArrayChatMessageContentItemRequest_String(StringChatMessageContentRequest):
    type: typing_extensions.Literal["STRING"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class ArrayChatMessageContentItemRequest_FunctionCall(FunctionCallChatMessageContentRequest):
    type: typing_extensions.Literal["FUNCTION_CALL"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class ArrayChatMessageContentItemRequest_Image(ImageChatMessageContentRequest):
    type: typing_extensions.Literal["IMAGE"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


ArrayChatMessageContentItemRequest = typing.Union[
    ArrayChatMessageContentItemRequest_String,
    ArrayChatMessageContentItemRequest_FunctionCall,
    ArrayChatMessageContentItemRequest_Image,
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .entity_status import EntityStatus
from .environment_enum import EnvironmentEnum
from .vellum_variable import VellumVariable

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class SlimDeploymentRead(pydantic.BaseModel):
    id: str
    created: dt.datetime
    label: str = pydantic.Field(description="A human-readable label for the deployment")
    name: str = pydantic.Field(description="A name that uniquely identifies this deployment within its workspace")
    status: typing.Optional[EntityStatus] = pydantic.Field(
        description=("The current status of the deployment\n" "\n" "- `ACTIVE` - Active\n" "- `ARCHIVED` - Archived\n")
    )
    environment: typing.Optional[EnvironmentEnum] = pydantic.Field(
        description=(
            "The environment this deployment is used in\n"
            "\n"
            "- `DEVELOPMENT` - Development\n"
            "- `STAGING` - Staging\n"
            "- `PRODUCTION` - Production\n"
        )
    )
    last_deployed_on: dt.datetime
    input_variables: typing.List[VellumVariable]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .indexing_state_enum import IndexingStateEnum

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class DocumentDocumentToDocumentIndex(pydantic.BaseModel):
    id: str = pydantic.Field(description="Vellum-generated ID that uniquely identifies this link.")
    document_index_id: str = pydantic.Field(
        description="Vellum-generated ID that uniquely identifies the index this document is included in."
    )
    indexing_state: typing.Optional[IndexingStateEnum] = pydantic.Field(
        description=(
            "An enum value representing where this document is along its indexing lifecycle for this index.\n"
            "\n"
            "- `AWAITING_PROCESSING` - Awaiting Processing\n"
            "- `QUEUED` - Queued\n"
            "- `INDEXING` - Indexing\n"
            "- `INDEXED` - Indexed\n"
            "- `FAILED` - Failed\n"
        )
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.jsonable_encoder import jsonable_encoder
from ...types.sandbox_metric_input_params_request import SandboxMetricInputParamsRequest
from ...types.sandbox_scenario import SandboxScenario
from ...types.scenario_input_request import ScenarioInputRequest

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class SandboxesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def upsert_sandbox_scenario(
        self,
        id: str,
        *,
        label: typing.Optional[str] = OMIT,
        inputs: typing.List[ScenarioInputRequest],
        scenario_id: typing.Optional[str] = OMIT,
        metric_input_params: typing.Optional[SandboxMetricInputParamsRequest] = OMIT,
    ) -> SandboxScenario:
        """
        Upserts a new scenario for a sandbox, keying off of the optionally provided scenario id.

        If an id is provided and has a match, the scenario will be updated. If no id is provided or no match
        is found, a new scenario will be appended to the end.

        Note that a full replacement of the scenario is performed, so any fields not provided will be removed
        or overwritten with default values.

        Parameters:
            - id: str. A UUID string identifying this sandbox.

            - label: typing.Optional[str].

            - inputs: typing.List[ScenarioInputRequest]. The inputs for the scenario

            - scenario_id: typing.Optional[str]. The id of the scenario to update. If none is provided, an id will be generated and a new scenario will be appended.

            - metric_input_params: typing.Optional[SandboxMetricInputParamsRequest].
        ---
        from vellum import (
            ChatMessageRequest,
            ChatMessageRole,
            EvaluationParamsRequest,
            SandboxMetricInputParamsRequest,
            ScenarioInputRequest,
            ScenarioInputTypeEnum,
        )
        from vellum.client import Vellum

        client = Vellum(
            api_key="YOUR_API_KEY",
        )
        client.sandboxes.upsert_sandbox_scenario(
            id="string",
            inputs=[
                ScenarioInputRequest(
                    key="string",
                    type=ScenarioInputTypeEnum.TEXT,
                    chat_history=[
                        ChatMessageRequest(
                            role=ChatMessageRole.SYSTEM,
                        )
                    ],
                )
            ],
            metric_input_params=SandboxMetricInputParamsRequest(
                params=EvaluationParamsRequest(),
            ),
        )
        """
        _request: typing.Dict[str, typing.Any] = {"inputs": inputs}
        if label is not OMIT:
            _request["label"] = label
        if scenario_id is not OMIT:
            _request["scenario_id"] = scenario_id
        if metric_input_params is not OMIT:
            _request["metric_input_params"] = metric_input_params
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", f"v1/sandboxes/{id}/scenarios"),
            json=jsonable_encoder(_request),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(SandboxScenario, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_sandbox_scenario(self, id: str, scenario_id: str) -> None:
        """
        Deletes an existing scenario from a sandbox, keying off of the provided scenario id.

        Parameters:
            - id: str. A UUID string identifying this sandbox.

            - scenario_id: str. An id identifying the scenario that you'd like to delete
        ---
        from vellum.client import Vellum

        client = Vellum(
            api_key="YOUR_API_KEY",
        )
        client.sandboxes.delete_sandbox_scenario(
            id="string",
            scenario_id="string",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "DELETE",
            urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/", f"v1/sandboxes/{id}/scenarios/{scenario_id}"
            ),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncSandboxesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def upsert_sandbox_scenario(
        self,
        id: str,
        *,
        label: typing.Optional[str] = OMIT,
        inputs: typing.List[ScenarioInputRequest],
        scenario_id: typing.Optional[str] = OMIT,
        metric_input_params: typing.Optional[SandboxMetricInputParamsRequest] = OMIT,
    ) -> SandboxScenario:
        """
        Upserts a new scenario for a sandbox, keying off of the optionally provided scenario id.

        If an id is provided and has a match, the scenario will be updated. If no id is provided or no match
        is found, a new scenario will be appended to the end.

        Note that a full replacement of the scenario is performed, so any fields not provided will be removed
        or overwritten with default values.

        Parameters:
            - id: str. A UUID string identifying this sandbox.

            - label: typing.Optional[str].

            - inputs: typing.List[ScenarioInputRequest]. The inputs for the scenario

            - scenario_id: typing.Optional[str]. The id of the scenario to update. If none is provided, an id will be generated and a new scenario will be appended.

            - metric_input_params: typing.Optional[SandboxMetricInputParamsRequest].
        ---
        from vellum import (
            ChatMessageRequest,
            ChatMessageRole,
            EvaluationParamsRequest,
            SandboxMetricInputParamsRequest,
            ScenarioInputRequest,
            ScenarioInputTypeEnum,
        )
        from vellum.client import AsyncVellum

        client = AsyncVellum(
            api_key="YOUR_API_KEY",
        )
        await client.sandboxes.upsert_sandbox_scenario(
            id="string",
            inputs=[
                ScenarioInputRequest(
                    key="string",
                    type=ScenarioInputTypeEnum.TEXT,
                    chat_history=[
                        ChatMessageRequest(
                            role=ChatMessageRole.SYSTEM,
                        )
                    ],
                )
            ],
            metric_input_params=SandboxMetricInputParamsRequest(
                params=EvaluationParamsRequest(),
            ),
        )
        """
        _request: typing.Dict[str, typing.Any] = {"inputs": inputs}
        if label is not OMIT:
            _request["label"] = label
        if scenario_id is not OMIT:
            _request["scenario_id"] = scenario_id
        if metric_input_params is not OMIT:
            _request["metric_input_params"] = metric_input_params
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", f"v1/sandboxes/{id}/scenarios"),
            json=jsonable_encoder(_request),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(SandboxScenario, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_sandbox_scenario(self, id: str, scenario_id: str) -> None:
        """
        Deletes an existing scenario from a sandbox, keying off of the provided scenario id.

        Parameters:
            - id: str. A UUID string identifying this sandbox.

            - scenario_id: str. An id identifying the scenario that you'd like to delete
        ---
        from vellum.client import AsyncVellum

        client = AsyncVellum(
            api_key="YOUR_API_KEY",
        )
        await client.sandboxes.delete_sandbox_scenario(
            id="string",
            scenario_id="string",
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "DELETE",
            urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/", f"v1/sandboxes/{id}/scenarios/{scenario_id}"
            ),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .document_document_to_document_index import DocumentDocumentToDocumentIndex
from .document_status import DocumentStatus
from .processing_failure_reason_enum import ProcessingFailureReasonEnum
from .processing_state_enum import ProcessingStateEnum

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class SlimDocument(pydantic.BaseModel):
    id: str = pydantic.Field(description="Vellum-generated ID that uniquely identifies this document.")
    external_id: typing.Optional[str] = pydantic.Field(
        description="The external ID that was originally provided when uploading the document."
    )
    last_uploaded_at: dt.datetime = pydantic.Field(
        description="A timestamp representing when this document was most recently uploaded."
    )
    label: str = pydantic.Field(description="Human-friendly name for this document.")
    processing_state: typing.Optional[ProcessingStateEnum] = pydantic.Field(
        description=(
            "An enum value representing where this document is along its processing lifecycle. Note that this is different than its indexing lifecycle.\n"
            "\n"
            "- `QUEUED` - Queued\n"
            "- `PROCESSING` - Processing\n"
            "- `PROCESSED` - Processed\n"
            "- `FAILED` - Failed\n"
        )
    )
    processing_failure_reason: typing.Optional[ProcessingFailureReasonEnum] = pydantic.Field(
        description=(
            "An enum value representing why the document could not be processed. Is null unless processing_state is FAILED.\n"
            "\n"
            "- `EXCEEDED_CHARACTER_LIMIT` - Exceeded Character Limit\n"
            "- `INVALID_FILE` - Invalid File\n"
        )
    )
    status: typing.Optional[DocumentStatus] = pydantic.Field(
        description=("The document's current status.\n" "\n" "- `ACTIVE` - Active\n")
    )
    keywords: typing.Optional[typing.List[str]] = pydantic.Field(
        description="A list of keywords associated with this document. Originally provided when uploading the document."
    )
    metadata: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(
        description="A previously supplied JSON object containing metadata that can be filtered on when searching."
    )
    document_to_document_indexes: typing.List[DocumentDocumentToDocumentIndex]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}
